@@ -5,13 +5,13 @@ from .issues import Issues, Issue
 
 
 MAX_FILE_SIZES = {
-    ".png": 1_000_000,  # 1 MB
-    ".jpg": 1_000_000,  # 1 MB
-    ".jpeg": 1_000_000,  # 1 MB
+    ".png": 10_000_000,  # 10 MB
+    ".jpg": 10_000_000,  # 10 MB
+    ".jpeg": 10_000_000,  # 10 MB
 }
 
 
-def sizeof_fmt(num):
+def sizeof_fmt(num: float) -> str:
     for unit in [" bytes", "KB", "MB", "GB"]:
         if abs(num) < 1000.0:
             return "%3.1f%s" % (num, unit)
@@ -20,10 +20,10 @@ def sizeof_fmt(num):
 
 
 class FileSizeCheck(Check):
-    def __init__(self, path):
+    def __init__(self, path: str) -> None:
         self.path = path
 
-    def run(self):
+    def run(self) -> Issues:
         issues = Issues()
 
         _, ext = os.path.splitext(self.path)
